summaryrefslogtreecommitdiff
path: root/board/snow/board.c
diff options
context:
space:
mode:
Diffstat (limited to 'board/snow/board.c')
-rw-r--r--board/snow/board.c11
1 files changed, 6 insertions, 5 deletions
diff --git a/board/snow/board.c b/board/snow/board.c
index 25122a85f8..8fe510a020 100644
--- a/board/snow/board.c
+++ b/board/snow/board.c
@@ -279,11 +279,12 @@ void board_pmu_init(void)
{
int ver;
- /*
- * Set fast charging timeout to 3hr.
- * Enable gpio charge_en control.
- */
- pmu_write(0x04, 0x06);
+ /* Set fast charging timeout to 6 hours*/
+ pmu_set_fastcharge(TIMEOUT_6HRS);
+ /* Enable external gpio CHARGER_EN control */
+ pmu_enable_ext_control(1);
+ /* Disable force charging */
+ pmu_enable_charger(0);
/* Set NOITERM bit */
pmu_low_current_charging(1);